import { Label, ProgressBar, _decorator } from "cc";
import GameSettingModule from "../../../lobbybundle/scripts/gamesetting/GameSettingModule";
import { PanelConfigs } from "../../../mainbundle/scripts/configs/PanelConfigs";
import { gg } from "../../../scripts/framework/gg";
import { PanelComponent, PanelShowOption, PanelHideOption } from "../../../scripts/framework/lib/router/PanelComponent";
import ZipFileMgr from "../../../scripts/zipfile/ZipFileMgr";
import LoadResConst from "../../../mainbundle/scripts/configs/LoadResConst";
import ConfigTableMgr from "../../../mainbundle/scripts/configtable/ConfigTableMgr";

const { ccclass, property } = _decorator;

/**
 * 启动页面板
 *
 * @author caizhitao
 * @created 2020-12-14 21:29:55
 */
@ccclass
export default class BootPanelPrefab extends PanelComponent {
    @property({
        type: ProgressBar,
        tooltip: "加载进度",
    })
    loadingProgressBar: ProgressBar = null;

    @property({
        type: Label,
        tooltip: "加载文本",
    })
    loadingLabel: Label = null;

    show(option: PanelShowOption): void {
        option.onShowed();
        this._initGame();
    }

    hide(option: PanelHideOption): void {
        option.onHided();
    }

    private async _initGame() {
        // 初始化游戏设置
        this._onLoadProgressChanged(0.1, "加载游戏设置...");
        GameSettingModule.initSettingConfig();

        // 提前加载通用弹窗面板
        this._onLoadProgressChanged(0.2, "加载游戏资源...");
        await gg.panelRouter.loadAsync(PanelConfigs.loadingPanel);

        this._onLoadProgressChanged(0.3, "加载游戏资源...");
        await gg.panelRouter.loadAsync(PanelConfigs.toastPanel);

        // 加载游戏设置面板
        this._onLoadProgressChanged(0.4, "加载游戏资源...");
        await gg.panelRouter.loadAsync(PanelConfigs.gameSettingPanel);

        // 加载游戏主面板
        this._onLoadProgressChanged(0.5, "加载游戏资源...");
        await gg.panelRouter.loadAsync(PanelConfigs.lobbyPanel);


        this._onLoadProgressChanged(0.7, "加载游戏配置...");
        await ConfigTableMgr.Inst.loadConfigTable();

        // 打开主面板
        this._onLoadProgressChanged(1.0);
        gg.panelRouter.show({
            panel: PanelConfigs.lobbyPanel,
            onShowed: () => {
                // 主面板打开完毕之后，隐藏并清理启动页面板相关资源（因为后续不会在用到）
                gg.panelRouter.hide({
                    panel: PanelConfigs.bootPanel,
                    onHided: () => {
                        gg.panelRouter.destroy({
                            panel: PanelConfigs.bootPanel,
                        });
                    },
                });
            },
        });
    }

    /**
     * 加载进度更新
     *
     * @param pb 加载进度 [0, 1]
     * @param msg 加载描述信息
     */
    private _onLoadProgressChanged(pb: number, msg: string = null) {
        this.loadingProgressBar.progress = pb;
        if (msg) {
            this.loadingLabel.string = msg;
        }
    }
}
