import { _decorator, Node, UIOpacity, Tween, tween, Vec3, v3 } from "cc";
import { PanelComponent, PanelShowOption, PanelHideOption } from "../../../scripts/framework/lib/router/PanelComponent";

const { ccclass, property } = _decorator;

export interface LoadingPanelShowArgs {
    /**
     * 展示时是否播放展示动画（不传则默认播放）
     */
    playShowAnim?: boolean;

    /**
     * 点击加载页面时回调
     */
    onCancelLoadingBtnClick?: Function;
}

/**
 * 游戏通用 Loading 面板
 *
 * @author caizhitao
 * @created 2020-12-07 20:47:19
 */
@ccclass("LoadingPanel")
export default class LoadingPanel extends PanelComponent {
    @property(Node)
    bgNode: Node = null;

    @property(Node)
    loadingSpriteNode: Node = null;

    private _showArgs: LoadingPanelShowArgs = null;

    onLoad() {
        this.bgNode.getComponent(UIOpacity).opacity = 0;
        this.loadingSpriteNode.getComponent(UIOpacity).opacity = 0;
    }

    show(option: PanelShowOption): void {
        this._showArgs = option.data;
        if (this._showArgs == null || this._showArgs.playShowAnim == null || this._showArgs.playShowAnim) {
            // 默认播放loading动画
            this._playPanelShowAnim(() => {
                option.onShowed();
            });
        } else {
            option.onShowed();
        }
    }

    hide(option: PanelHideOption): void {
        this._playPanelHideAnim(() => {
            this._showArgs = null;
            option.onHided();
        });
    }

    private _playPanelShowAnim(onAnimCompleted: Function) {
        Tween.stopAllByTarget(this.bgNode);
        tween<UIOpacity>(this.bgNode.getComponent(UIOpacity))
            .set({ opacity: 0 })
            .to(0.24, { opacity: 220 }, { easing: "sineOut" })
            .call(() => {
                onAnimCompleted();
            })
            .start();
        Tween.stopAllByTarget(this.loadingSpriteNode);
        tween<UIOpacity>(this.loadingSpriteNode.getComponent(UIOpacity)).set({ opacity: 0, }).to(0.24, { opacity: 255 }, { easing: "sineOut" }).start();
        tween(this.loadingSpriteNode).set({ scale: new Vec3(2, 2, 1) }).to(0.24, { scale: new Vec3(1, 1, 1) }, { easing: "sineOut" }).start();
        tween(this.loadingSpriteNode)
            .repeatForever(tween().by(0.7, { angle: -360 }))
            .start();
    }

    private _playPanelHideAnim(onAnimCompleted: Function) {
        Tween.stopAllByTarget(this.bgNode);
        tween<UIOpacity>(this.bgNode.getComponent(UIOpacity))
            .to(0.24, { opacity: 0 }, { easing: "sineOut" })
            .call(() => {
                onAnimCompleted();
            })
            .start();
        Tween.stopAllByTarget(this.loadingSpriteNode);
        tween(this.loadingSpriteNode).to(0.24, { scale: v3() }, { easing: "sineOut" }).start();

        Tween.stopAllByTarget(this.loadingSpriteNode.getComponent(UIOpacity));
        tween(this.loadingSpriteNode.getComponent(UIOpacity)).to(0.24, { opacity: 0 }, { easing: "sineOut" }).start();
    }

    onCancelLoadingBtnClick() {
        this._showArgs && this._showArgs.onCancelLoadingBtnClick && this._showArgs.onCancelLoadingBtnClick();
    }
}
