import { _decorator, Node, Slider, Button, Toggle, Tween, tween, UIOpacity, v3 } from "cc";
import { gg } from "../../../scripts/framework/gg";
import { GameSettingEvent } from "./GameSettingEvent";
import GameSettingModule from "./GameSettingModule";
import { PanelConfigs } from "../../../mainbundle/scripts/configs/PanelConfigs";
import { PanelComponent, PanelShowOption, PanelHideOption } from "../../../scripts/framework/lib/router/PanelComponent";

const { ccclass, property } = _decorator;

/**
 * 游戏设置面板
 *
 * @author caizhitao
 * @created 2020-12-10 21:03:06
 */
@ccclass
export default class GameSettingPanelPrefab extends PanelComponent {
    @property(Node)
    dialogBgNode: Node = null;

    @property(Node)
    dialogContentNode: Node = null;

    @property(Slider)
    musicVolumeSlider: Slider = null;

    @property(Slider)
    soundVolumeSlider: Slider = null;

    @property(Toggle)
    vibrateToggle: Toggle = null;

    @property({
        type: [Button],
        tooltip: "关闭按钮",
    })
    closeBtns: Button[] = [];

    onLoad() {
        this.musicVolumeSlider.node.on("slide", this._onMusicVolumeChanged, this);
        this.soundVolumeSlider.node.on("slide", this._onSoundVolumeChanged, this);
        this.vibrateToggle.node.on("toggle", this._onVibrateChanged, this);
    }

    show(option: PanelShowOption): void {
        // 显示最新的游戏配置
        this.musicVolumeSlider.progress = GameSettingModule.data.musicVolume;
        this.soundVolumeSlider.progress = GameSettingModule.data.soundVolume;
        this.vibrateToggle.isChecked = GameSettingModule.data.enableVibrate;

        // 让关闭按钮可以点击
        this.closeBtns.forEach((clostBtn) => {
            clostBtn.interactable = true;
        });

        // 播放展示动画
        this._playPanelShowAnim(() => {
            option.onShowed();
        });
    }

    hide(option: PanelHideOption): void {
        // 让关闭按钮不可以点击
        this.closeBtns.forEach((clostBtn) => {
            clostBtn.interactable = false;
        });

        // 面板退出的时候，持久化游戏设置，保存到本地缓存中
        GameSettingModule.saveSettingConfig();

        // 播放隐藏动画
        this._playPanelHideAnim(() => {
            option.onHided();
        });
    }

    onCloseBtnClick() {
        gg.panelRouter.hide({
            panel: PanelConfigs.gameSettingPanel,
        });
    }

    private _onMusicVolumeChanged(slider: Slider) {
        GameSettingModule.data.musicVolume = slider.progress;
        gg.eventManager.emit(GameSettingEvent.OnMusicVolumeChanged);
    }

    private _onSoundVolumeChanged(slider: Slider) {
        GameSettingModule.data.soundVolume = slider.progress;
        gg.eventManager.emit(GameSettingEvent.OnSoundVolumeChanged);
    }

    private _onVibrateChanged(toggle: Toggle) {
        GameSettingModule.data.enableVibrate = toggle.isChecked;
        gg.eventManager.emit(GameSettingEvent.OnVibrateChanged);
    }

    private _playPanelShowAnim(onAnimCompleted: Function) {
        Tween.stopAllByTarget(this.dialogBgNode.getComponent(UIOpacity));
        tween(this.dialogBgNode.getComponent(UIOpacity)).set({ opacity: 0 }).to(0.24, { opacity: 220 }, { easing: "sineOut" }).start();

        Tween.stopAllByTarget(this.dialogContentNode.getComponent(UIOpacity));
        tween(this.dialogContentNode.getComponent(UIOpacity))
            .set({ opacity: 0 })
            .to(0.24, { opacity: 255 }, { easing: "sineOut" })
            .call(() => {
                onAnimCompleted();
            })
            .start();

        // Tween.stopAllByTarget(this.dialogContentNode);
        tween<Node>(this.dialogContentNode)
            .set({ position: v3(0, 100, 0) })
            .to(0.24, { position: v3() }, { easing: "sineOut" })
            .call(() => {
                onAnimCompleted();
            })
            .start();
    }

    private _playPanelHideAnim(onAnimCompleted: Function) {
        Tween.stopAllByTarget(this.dialogBgNode.getComponent(UIOpacity));
        tween(this.dialogBgNode.getComponent(UIOpacity)).to(0.24, { opacity: 0 }, { easing: "sineOut" }).start();

        Tween.stopAllByTarget(this.dialogContentNode.getComponent(UIOpacity));
        tween(this.dialogContentNode.getComponent(UIOpacity))
            .to(0.24, { opacity: 0 }, { easing: "sineOut" })
            .call(() => {
                onAnimCompleted();
            })
            .start();

        Tween.stopAllByTarget(this.dialogContentNode);
        tween<Node>(this.dialogContentNode)
            .to(0.24, { position: v3(0, 100, 0) }, { easing: "sineOut" })
            .call(() => {
                onAnimCompleted();
            })
            .start();
    }
}
