import LoadResConst from "../configs/LoadResConst";
import ZipFileMgr from "../../../scripts/zipfile/ZipFileMgr";
import { TableFileConfigs } from "../configs/TableFileConfigs";
import { CFGTableFASkill } from "./model/CFGTableFASkill";
import { CFGTableFABuff } from "./model/CFGTableFABuff";
import { CFGTableFAHero } from "./model/CFGTableFAHero";
import { CFGTableFAHeroLevel } from "./model/CFGTableFAHeroLevel";
import { CFGTableFAHeroStar } from "./model/CFGTableFAHeroStar";
import { CFGTableFAMap } from "./model/CFGTableFAMap";
import { CFGTableFATower } from "./model/CFGTableFATower";
import { gg } from "../../../scripts/framework/gg";
import CFGTableBase from "./base/CFGTableBase";

export default class ConfigTableMgr {
    private static TAG: string = "ConfigTableMgr";
    private static _inst: ConfigTableMgr;
    private _allTableMap: any;

    public static get Inst(): ConfigTableMgr {
        if (ConfigTableMgr._inst == null) {
            ConfigTableMgr._inst = new ConfigTableMgr();
        }
        return ConfigTableMgr._inst;
    }

    public async loadConfigTable() {
        let jsontable = await ZipFileMgr.Inst.getJsonList(LoadResConst.ConfigTable);
        let obj: any = {};
        for (const tablename in jsontable) {
            if (Object.prototype.hasOwnProperty.call(jsontable, tablename)) {
                obj[tablename] = {};
                let tablelist: any[] = jsontable[tablename];
                for (let i: number = 0; i < tablelist.length; i++) {
                    let vo: CFGTableBase = this.resetData(tablename, tablelist[i]);
                    obj[tablename][vo.id] = vo;
                }
                gg.logger.info(ConfigTableMgr.TAG, "loadConfigTable->表数据重置完成 tablename: ", tablename);
            }
        }
        this._allTableMap = obj;
        gg.logger.info(ConfigTableMgr.TAG, "loadConfigTable->配置表解析完成");
    }

    private resetData(name: string, obj: any): any {
        let itemcls: any = null;
        switch (name) {
            case TableFileConfigs.FightA_Skill:
                itemcls = CFGTableFASkill;
                break;
            case TableFileConfigs.FightA_Buff:
                itemcls = CFGTableFABuff;
                break;
            case TableFileConfigs.FightA_Hero:
                itemcls = CFGTableFAHero;
                break;
            case TableFileConfigs.FightA_HeroLevel:
                itemcls = CFGTableFAHeroLevel;
                break;
            case TableFileConfigs.FightA_HeroStar:
                itemcls = CFGTableFAHeroStar;
                break
            case TableFileConfigs.FightA_Map:
                itemcls = CFGTableFAMap;
                break;
            case TableFileConfigs.FightA_Tower:
                itemcls = CFGTableFATower;
                break;
            default:
                gg.logger.warn(ConfigTableMgr.TAG, "resetData->没有对应解析类: name: ", name);
                break;
        }
        if (itemcls) {
            let ic: CFGTableBase = new itemcls();
            ic.creatbyObj(obj);
            return ic;
        }
        return obj;
    }

    /**
     * 根据表名和id获取数据元素
     * @param tablename @type TableFileConfigs
     * @param id 
     */
    public getConfItemById(tablename: TableFileConfigs, id: string): CFGTableBase {
        if (!this._allTableMap[tablename]) {
            gg.logger.warn(ConfigTableMgr.TAG, "getConfTableById->没有对应数据: tablename: " + tablename);
            return null;
        }
        if (!this._allTableMap[tablename][id]) {
            gg.logger.warn(ConfigTableMgr.TAG, "getConfTableById->没有对应ID: tablename: " + tablename + " id: " + id);
            return null;
        }
        return this._allTableMap[tablename][id];
    }

    /**
     * 根据表名获取数据表
     * @param tablename @type TableFileConfigs
     */
    public getTableByName(tablename: TableFileConfigs): CFGTableBase[] {
        if (!this._allTableMap[tablename]) {
            gg.logger.warn(ConfigTableMgr.TAG, "getTableByName->没有对应数据: tablename: " + tablename);
            return null;
        }
        return this._allTableMap[tablename];
    }
}