import PanelRouter from "./lib/router/PanelRouter";
import EventManager from "./lib/eventmanager/EventManager";
import { EventManagerInterface } from "./lib/eventmanager/EventManagerInterface";
import CCLogger from "./lib/logger/CCLogger";
import { LoggerInterface } from "./lib/logger/LoggerInterface";
import NativeLogger from "./lib/logger/NativeLogger";
import { sys } from "cc";

/**
 * 框架接口
 */
export interface FrameworkInterface {
    /**
     * 日志接口
     */
    logger: LoggerInterface;

    /**
     * 事件广播、监听、注销管理器接口
     */
    eventManager: EventManagerInterface;

    /**
     * 面板路由器接口
     */
    panelRouter: PanelRouter;
}

/**
 * GoGame 框架入口
 */
export const gg: FrameworkInterface = {
    logger: ((): LoggerInterface => {
        // return new CCLogger();
        if (sys.isNative) {
            return new NativeLogger();
        } else {
            return new CCLogger();
        }
    })(),
    eventManager: new EventManager(),
    panelRouter: new PanelRouter()
};
