import { Asset, AssetManager, assetManager } from "cc";
import { ILoadResInfo } from "./interfaces/ILoadResInfo";
import { gg } from "../framework/gg";

export default class LoadMgr {
    private static TAG: string = "LoadMgr";
    private static _inst: LoadMgr;

    public static get Inst(): LoadMgr {
        if (LoadMgr._inst == null) {
            LoadMgr._inst = new LoadMgr();
        }
        return LoadMgr._inst;
    }

    /**
     * 同步加载资源
     * @param resInfo 
     */
    public async getAssetAsync<T extends Asset>(resInfo: ILoadResInfo): Promise<T> {
        return new Promise<T>((resolve, reject) => {
            let loadBundlePrefab = (bundle: AssetManager.Bundle) => {
                bundle.load(resInfo.path, Asset, (error: Error, resLoad: T) => {
                    gg.logger.log(LoadMgr.TAG + "::getAssetAsync-> ", resLoad);
                    error ? resolve(null) : resolve(resLoad);
                });
            };

            let bundle: AssetManager.Bundle = assetManager.getBundle(resInfo.bundle);
            if (bundle == null) {
                gg.logger.warn(LoadMgr.TAG + "::getAssetAsync-> " + resInfo.bundle + " auto load 加载开始");
                assetManager.loadBundle(resInfo.bundle, (error: Error, bundle: AssetManager.Bundle) => {
                    gg.logger.log(LoadMgr.TAG + "::getAssetAsync-> " + resInfo.bundle + " auto load 加载完成");
                    loadBundlePrefab(bundle);
                });
            } else {
                loadBundlePrefab(bundle);
            }
        });
    }

    /**
     * 异步(回调方式)加载资源
     * @param resInfo 
     */
    public getAsset<T extends Asset>(resInfo: ILoadResInfo, callback: Function): void {
        let loadBundlePrefab = (bundle: AssetManager.Bundle) => {
            bundle.load(resInfo.path, Asset, (error: Error, resLoad: T) => {
                gg.logger.log(LoadMgr.TAG + "::getAsset-> error: ", error, " resLoad:", resLoad);
                error ? callback(null) : callback(resLoad);
            });
        };
        let bundle: AssetManager.Bundle = assetManager.getBundle(resInfo.bundle);
        if (bundle == null) {
            gg.logger.warn(LoadMgr.TAG + "::getAsset-> " + resInfo.bundle + " auto load 加载开始");
            assetManager.loadBundle(resInfo.bundle, (error: Error, bundle: AssetManager.Bundle) => {
                gg.logger.log(LoadMgr.TAG + "::getAsset-> " + resInfo.bundle + " auto load 加载完成");
                loadBundlePrefab(bundle);
            });
        } else {
            loadBundlePrefab(bundle);
        }
    }

}